FullOps

Trait FullOps 

pub trait FullOps: Sized {
    // Required methods
    fn full_mul_add(
        self,
        other: Self,
        other2: Self,
        carry: Self,
    ) -> (Self, Self);
    fn full_div_rem(self, other: Self, borrow: Self) -> (Self, Self);
}
🔬This is a nightly-only experimental API. (core_private_bignum)
Arithmetic operations required by bignums.

Required Methods

fn full_mul_add(self, other: Self, other2: Self, carry: Self) -> (Self, Self)

🔬This is a nightly-only experimental API. (core_private_bignum)

Returns (carry', v') such that carry' * 2^W + v' = self * other + other2 + carry, where W is the number of bits in Self.

fn full_div_rem(self, other: Self, borrow: Self) -> (Self, Self)

🔬This is a nightly-only experimental API. (core_private_bignum)

Returns (quo, rem) such that borrow * 2^W + self = quo * other + rem and 0 <= rem < other, where W is the number of bits in Self.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors